package ch.zhaw.projekt2.turnierverwaltung;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.format.DateTimeFormatter;

public class Player extends Person implements Participant{

    private LocalDate dateOfBirth;

    public Player(String firstName, String name, String phoneNumber, String dateOfBirth) throws InvalidNameException, InvalidPhoneNumberException, InvalidDateException {
        super(firstName, name, phoneNumber);
        setDateOfBirth(dateOfBirth);
    }

    public LocalDate getDateOfBirth() {
        return dateOfBirth;
    }

    public String getFormatedDateOfBirth(){
        try{
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("dd.MM.yyyy");
            return dateOfBirth.format(formatter);
        } catch (Exception e) {
           //todo handle and logging
            return "";
        }
    }

    public void setDateOfBirth(String dateOfBirth) throws InvalidDateException {
        if(dateOfBirth.length() > 0) {
            String[] date = dateOfBirth.split("\\.");
            try{
                this.dateOfBirth = LocalDate.of(Integer.valueOf(date[2]), Integer.valueOf(date[1]), Integer.valueOf(date[0]));
            } catch (NumberFormatException e) {
                e.printStackTrace();
                throw new InvalidDateException("Date invalid");
            }

        } else {
            dateOfBirth = null;
        }
    }

    public void setDateOfBirth(LocalDate dateOfBirth) {
        this.dateOfBirth = dateOfBirth;
    }

    @Override
    public boolean equals(Participant participant) {
        return getClass().equals(participant.getClass()) && toString().toLowerCase().equals(participant.toString().toLowerCase());
    }

    @Override
    public void change(Participant participant) {
        Player player = (Player) participant;
        setDateOfBirth(player.getDateOfBirth());
        setPhoneNumber(player.getPhoneNumber());
    }

    public class InvalidDateException extends Exception {
        public InvalidDateException() {
            super();
        }

        public InvalidDateException(String errorMessage) {
            super(errorMessage);
        }

    }

}
